import React, { useRef, useEffect } from "react";
import styled from "styled-components";
import usePano from "./usePano";
import { useTargetPoint, usePanoStartPosition, usePanoStartPov } from "../../../domain/gameStore";
import { savePanoPositionToLocalStorage, savePanoPovToLocalStorage } from "../../../domain/localStorageMethods";

const Container = styled.div`
  position: relative;
  height: 100%;
  width: 100%;
`

const Pano = styled.div`
  height: 100%;
  width: 100%;
`

const ResetButton = styled.div`
  /* TODO improve this to be less brittle */
  display: block;
  position: absolute;
  z-index: 1;
  bottom: 200px;
  right: 9px;
  background-color: #222;
  color: #666;
  padding: 5px;
  border-radius: 2px;
  font-weight: bold;
  cursor: pointer;

  &:hover {
    color: #b1b1b1;
  }
`

export default () => {
  const startPosition = usePanoStartPosition();
  const startPov = usePanoStartPov();
  const resetPosition = useTargetPoint();
  const panoDivRef = useRef(null);
  const panoRef = usePano(panoDivRef, startPosition, startPov);
  useEffect(() => {
    if (panoRef.current) {
      panoRef.current.addListener("position_changed", () => {
        const { lat, lng } = panoRef.current.getPosition();
        savePanoPositionToLocalStorage(lat(), lng());
      });
      panoRef.current.addListener("pov_changed", () => {
        const { heading, pitch } = panoRef.current.getPov();
        savePanoPovToLocalStorage(heading, pitch);
      });
    }
  }, [panoRef]);

  return (
    <Container>
      <Pano ref={panoDivRef}/>
      <ResetButton onClick={() => panoRef.current.setPosition(resetPosition)}>
        Reset
      </ResetButton>
    </Container>
  );
};
