import React from 'react';
import styled from 'styled-components';
import GameCreationForm from '../util/GameCreationForm';
import { dispatch } from '../../domain/gameStore';
import { hasSavedGameInfo } from '../../domain/localStorageMethods';
import DelayedButton from '../util/DelayedButton';

const Container = styled.div`
  height: 100%;
  display: flex;
  flex-flow: column nowrap;
  justify-content: center;
  align-items: center;
`;

const RejoinLabel = styled.span`
  margin-bottom: 0.5em;
`;

const RejoinContainer = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: flex-end;
  align-items: center;
`;

const Rejoin = () => (
  <RejoinContainer>
    <RejoinLabel>Looks like you were in a game before that you didn't finish!</RejoinLabel>
    <DelayedButton 
      onEnd={() => dispatch.rejoinGame()}
      countDownFormatter={rem => `Rejoining in ${rem}s...`}
    >
      Rejoin Game?
    </DelayedButton>
  </RejoinContainer>
);

export default () => (
  <Container>
    <GameCreationForm afterCreate={gameId => dispatch.goToLobby(gameId)}/>
    {hasSavedGameInfo() && <Rejoin />}
  </Container>
);