import React, { useState } from "react";
import styled from "styled-components";
import ms from "pretty-ms";
import Loading from "./Loading";
import Button from "./Button";
import { createGame } from "../../domain/apiMethods";
import Dropdown from "./Dropdown";
import { MAP_CRUNCH, RANDOM_STREET_VIEW } from "../../domain/genMethods";

const Container = styled.div`
  display: flex;
  flex-flow: row nowrap;
  justify-content: space-between;
  align-self: center;
`

const DropdownContainer = styled.div`
  flex: 3;
  margin-right: 5px;
  display: flex;
  flex-flow: column nowrap;
  justify-content: flex-start;
  align-items: flex-start;
`;

const StartButton = styled(Button)`
  flex: 1;
  margin-bottom: 5px;
`

export default ({ afterCreate }) => {
  const [loading, setLoading] = useState(false);
  const [timer, setTimer] = useState(300);
  const [rounds, setRounds] = useState(5);
  const [onlyAmerica, setOnlyAmerica] = useState(false);
  const [genMethod, setGenMethod] = useState(MAP_CRUNCH);

  if (loading) {
    return <Loading/>
  }

  const onCreateGame = async () => {
    setLoading(true);
    const gameId = await createGame(timer, rounds, onlyAmerica, genMethod);
    if (afterCreate) {
      afterCreate(gameId);
    }
  };

  return (
    <Container>
      <DropdownContainer>
        <Dropdown
          options={{
            "30 Seconds": 30,
            "2 Minutes": 120,
            "5 Minutes": 300,
            "1 Hour": 3600,
          }}
          onChange={setTimer}
        >
          Round Timer: {ms(timer * 1000)}
        </Dropdown>
        <Dropdown
          options={{
            "1 Round": 1,
            "3 Rounds": 3,
            "5 Rounds": 5,
            "10 Rounds": 10,
          }}
          onChange={setRounds}
        >
          Rounds: {rounds}
        </Dropdown>
        <Dropdown
          options={{
            "All Countries": false,
            "Just America": true,
          }}
          onChange={setOnlyAmerica}
        >
          {onlyAmerica ? "Just America" : "All Countries" }
        </Dropdown>
        <Dropdown
          options={{
            "Map Crunch": MAP_CRUNCH,
            "Random Street View": RANDOM_STREET_VIEW,
          }}
          onChange={setGenMethod}
        >
          Generator: {genMethod === MAP_CRUNCH ? "Map Crunch" : "RSV" }
        </Dropdown>
      </DropdownContainer>
      <StartButton onClick={onCreateGame}>
        New Game
      </StartButton>
    </Container>
  );
}
